==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Surveys/language/lang-dutch.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_YOURNAME","Uw naam");
define("_OK","Ok!");
define("_COMMENT","Opmerkingen");
define("_CONFIGURE","Aanpassen");
define("_LOGINCREATE","Login/Creer een account");
define("_THRESHOLD","Limiet");
define("_NOCOMMENTS","Geen opmerkingen");
define("_NESTED","Genest");
define("_FLAT","Plat");
define("_THREAD","Draad");
define("_OLDEST","Oudste eerst");
define("_NEWEST","Nieuwste eerst");
define("_HIGHEST","Meest gelezen eerst");
define("_COMMENTSWARNING","De schrijver is verantwoordelijk voor de inhoud van zijn berichten. 
define("_SCORE","Score:");
define("_USERINFO","Gebruikersinformatie");
define("_READREST","Lees de rest van deze opmerking...");
define("_REPLY","Reageer op dit bericht");
define("_REPLYMAIN","Opmerking plaatsen");
define("_NOSUBJECT","Geen onderwerp");
define("_NOANONCOMMENTS","Gasten mogen geen opmerkingen plaatsen, <a href=\"modules.php?name=Your_Account\">registreer</a> a.u.b.");
define("_PARENT","Parent");
define("_ROOT","Root");
define("_UCOMMENT","Opmerking");
define("_ALLOWEDHTML","Toegestane HTML:");
define("_POSTANON","Anoniem plaatsen");
define("_EXTRANS","Extrans (HTML-tags naar tekst)");
define("_HTMLFORMATED","HTML Geformatteerd");
define("_PLAINTEXT","Alleen tekst");
define("_ONN","op...");
define("_SUBJECT","Onderwerp");
define("_SURVEYCOM","Onderzoek opmerking plaatsen");
define("_SURVEYCOMPRE","Onderzoek opmerking plaatsen voorbeeld");
define("_NOTRIGHT","Fout in een functievariabele.");
define("_DIRECTCOM","Direct onderzoek opmerking...");
define("_SENDAMSG","Stuur een bericht");
define("_PASTSURVEYS","Voorgaande onderzoeken");



define("_LVOTES","Stemmen");
define("_TOTALVOTES","Totaal aantal stemmen:");
define("_VOTING","Stemming");
define("_OTHERPOLLS","Andere peilingen");
define("_CURRENTSURVEY","Huidig onderzoek");
define("_CURRENTPOLLRESULTS","Uitslagen actuele peiling");
define("_PREVIEW","Preview");
define("_REFRESH","Vernieuw");
define("_SURVEYS","Onderzoeken");
define("_ATTACHEDTOARTICLE","- Toegevoegd aan artikel:");
define("_SURVEYSATTACHED","Onderzoeken toegevoegd aan artikel");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Surveys/language/lang-dutch.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_YOURNAME","Uw naam");
define("_OK","Ok!");
define("_COMMENT","Opmerkingen");
define("_CONFIGURE","Aanpassen");
define("_LOGINCREATE","Login/Creer een account");
define("_THRESHOLD","Limiet");
define("_NOCOMMENTS","Geen opmerkingen");
define("_NESTED","Genest");
define("_FLAT","Plat");
define("_THREAD","Draad");
define("_OLDEST","Oudste eerst");
define("_NEWEST","Nieuwste eerst");
define("_HIGHEST","Meest gelezen eerst");
define("_COMMENTSWARNING","De schrijver is verantwoordelijk voor de inhoud van zijn berichten. 
define("_SCORE","Score:");
define("_USERINFO","Gebruikersinformatie");
define("_READREST","Lees de rest van deze opmerking...");
define("_REPLY","Reageer op dit bericht");
define("_REPLYMAIN","Opmerking plaatsen");
define("_NOSUBJECT","Geen onderwerp");
define("_NOANONCOMMENTS","Gasten mogen geen opmerkingen plaatsen, <a href=\"modules.php?name=Your_Account\">registreer</a> a.u.b.");
define("_PARENT","Parent");
define("_ROOT","Root");
define("_UCOMMENT","Opmerking");
define("_ALLOWEDHTML","Toegestane HTML:");
define("_POSTANON","Anoniem plaatsen");
define("_EXTRANS","Extrans (HTML-tags naar tekst)");
define("_HTMLFORMATED","HTML Geformatteerd");
define("_PLAINTEXT","Alleen tekst");
define("_ONN","op...");
define("_SUBJECT","Onderwerp");
define("_SURVEYCOM","Onderzoek opmerking plaatsen");
define("_SURVEYCOMPRE","Onderzoek opmerking plaatsen voorbeeld");
define("_NOTRIGHT","Fout in een functievariabele.");
define("_DIRECTCOM","Direct onderzoek opmerking...");
define("_SENDAMSG","Stuur een bericht");
define("_PASTSURVEYS","Voorgaande onderzoeken");



define("_LVOTES","Stemmen");
define("_TOTALVOTES","Totaal aantal stemmen:");
define("_VOTING","Stemming");
define("_OTHERPOLLS","Andere peilingen");
define("_CURRENTSURVEY","Huidig onderzoek");
define("_CURRENTPOLLRESULTS","Uitslagen actuele peiling");
define("_PREVIEW","Preview");
define("_REFRESH","Vernieuw");
define("_SURVEYS","Onderzoeken");
define("_ATTACHEDTOARTICLE","- Toegevoegd aan artikel:");
define("_SURVEYSATTACHED","Onderzoeken toegevoegd aan artikel");

?>
